Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2019-02-27 04:02:02 +0300
committerCampbell Barton <ideasman42@gmail.com>2019-02-27 04:26:49 +0300
commit1079742db92576d79ec89a28d95336aff847a82a (patch)
tree2e440e498c20d3205c2a64eedf4f84bf57abcb84 /source/blender/collada/collada_utils.cpp
parent918941483f7ec5fc6320d345c755e953b963c710 (diff)
Cleanup: rename lamp -> light
Diffstat (limited to 'source/blender/collada/collada_utils.cpp')
-rw-r--r--source/blender/collada/collada_utils.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/collada/collada_utils.cpp b/source/blender/collada/collada_utils.cpp
index 66c8f94b6c8..406d4dabc88 100644
--- a/source/blender/collada/collada_utils.cpp
+++ b/source/blender/collada/collada_utils.cpp
@@ -1016,9 +1016,9 @@ bool bc_is_animated(BCMatrixSampleMap &values)
bool bc_has_animations(Object *ob)
{
/* Check for object,lamp and camera transform animations */
if ((bc_getSceneObjectAction(ob) && bc_getSceneObjectAction(ob)->curves.first) ||
- (bc_getSceneLampAction(ob) && bc_getSceneLampAction(ob)->curves.first) ||
+ (bc_getSceneLightAction(ob) && bc_getSceneLightAction(ob)->curves.first) ||
(bc_getSceneCameraAction(ob) && bc_getSceneCameraAction(ob)->curves.first))
return true;
@@ -1016,9 +1016,9 @@ bool bc_is_animated(BCMatrixSampleMap &values)
bool bc_has_animations(Object *ob)
{
- /* Check for object,lamp and camera transform animations */
+ /* Check for object, light and camera transform animations */
if ((bc_getSceneObjectAction(ob) && bc_getSceneObjectAction(ob)->curves.first) ||